# Aerosol functions
A collection of functions to analyze atmospheric aerosol data. Use [pip](https://pip.pypa.io/en/stable/) to install the package
```shell
pip install aerosol-functions
```
See [documentation](https://jlpl.github.io/aerosol-functions/)
